#!/bin/bash

# Store script directory to variable
script_file="$(find ~+ -name update_evcc.sh)"
script_dir="$(dirname "${script_file}")"

echo "Script dir: $script_dir"

# Get evcc path
printf "\nsearching for existing evcc installation...\n"
evcc_binary="$(which evcc)"
evcc_directory="$(dirname "${evcc_binary}")"

# Check if evcc installation exists
if [ -n $evcc_binary ]
then

	printf "evcc found in $evcc_directory\n"
	
	# Changing working directory
	cd $evcc_directory
	
	# Check if file exists
	if [ -n $script_dir/evcc ]
	then
		
		# Stop evcc
		printf "\nStopping evcc...\n"
		systemctl stop evcc
		
		# Checking installed evcc version
		printf "\nInstalled version of evcc is: "
		evcc -v
		
		# Copy new binary file to target
		cp $script_dir/evcc $evcc_binary
		
		# Restoring permissions
		chmod 755 $evcc_binary
		
		# Checking installed evcc version after replacing file
		printf "\nInstalled version of evcc after update: "
		evcc -v
		
		# Check for existing evcc config
		evcc_config="$(find / -type f -name evcc.yaml)"
		if test -n "$evcc_config"; then
			printf "\nevcc configuration file found in: $evcc_config"
			
			# Checking evcc.yaml for existance of em2go template
			if [ $(grep -c " template: em2go " $evcc_config) -eq 1 ]
			then
				printf "\nFound generic em2go template in evcc.yaml.\n"
				grep -c "template: em2go" $evcc_config
				
				# Changing template from em2go to em2go-home
				printf "\nReplacing generic template em2go with em2go-home for compatibility for EM2GO Home series.\n"
				sed -i 's/  template: em2go /  template: em2go-home /g' $evcc_config
				# Remove ID from template parameters
				sed -z 's/template: em2go-home \n  id: 255/template: em2go-home /' -i $evcc_config
				# Remove port and modbus from template parameters
				sed -z 's/port: 502  \n  modbus: tcpip  \n  name: wallbox/name: wallbox/' -i $evcc_config
			fi
			
		else
			printf "\nNo configuration file for evcc found.\n"
			while true; do
				read -p "Do you wish to create a new evcc configuration? Press y for yes or n for no and pres ENTER to continue." yn
				case $yn in
					[Yy]* ) cd /etc/ && evcc configure && break;;
					[Nn]* ) break;;
					* ) printf "Please answer y for yes or n for no.\n";;
				esac
			done
		fi
		
		# Start evcc
		printf "\nStarting evcc: "
		systemctl start evcc
		systemctl is-active evcc
		
		printf "\n\nevcc has been updated successfully.\n"

	else
	
		printf "\nFiles not found. Please unzip files again and retry\n"
	
	fi

else

	printf "\nNo installation of evcc found! Please install evcc first.\n"
	printf "For instructions please visit https://docs.evcc.io/docs/installation/linux\n"
	
fi